summaryrefslogtreecommitdiff
path: root/lib/cache.php
diff options
context:
space:
mode:
authorBrion Vibber <brion@pobox.com>2010-02-05 09:47:56 -0800
committerBrion Vibber <brion@pobox.com>2010-02-05 09:47:56 -0800
commit875e1a70ce231b6b07765210328656abb353ad5b (patch)
tree81fe1cd01946cd2e19b4e938d669c3ea1ff4bd32 /lib/cache.php
parent8d320d7cc2998a4977c5de4ba571ea4f95b21dce (diff)
Don't spew warnings on usage of MEMCACHE_COMPRESSED constant when memcache PHP extension is not present.
Switched to a locally-defined Cache::COMPRESSED, translating that to MEMCACHE_COMPRESSED in the plugin.
Diffstat (limited to 'lib/cache.php')
-rw-r--r--lib/cache.php4
1 files changed, 3 insertions, 1 deletions
diff --git a/lib/cache.php b/lib/cache.php
index 635c96ad4..df6fc3649 100644
--- a/lib/cache.php
+++ b/lib/cache.php
@@ -47,6 +47,8 @@ class Cache
var $_items = array();
static $_inst = null;
+ const COMPRESSED = 1;
+
/**
* Singleton constructor
*
@@ -133,7 +135,7 @@ class Cache
*
* @param string $key The key to use for lookups
* @param string $value The value to store
* @param integer $flag Flags to use, mostly ignored
* @param integer $expiry Expiry value, mostly ignored
*
* @return boolean success flag
@@ -133,7 +135,7 @@ class Cache
* @param string $key The key to use for lookups
* @param string $value The value to store
- * @param integer $flag Flags to use, mostly ignored
+ * @param integer $flag Flags to use, may include Cache::COMPRESSED
* @param integer $expiry Expiry value, mostly ignored
*